"""mssdk 是基于 Python 的为麦思多维科技客户服务的专用API接口"""

"""
0.0.1
发布测试版本
"""

__version__ = '0.0.1'
__author__ = 'mssdk'


"""
for mssdk pro api
"""
from mssdk.pro.data_pro import pro_api

"""
for mssdk pro api token set
"""
from mssdk.utils.token_process import set_token



# -*- coding:utf-8 -*-
# /usr/bin/env python
"""
Date: 2020/4/23 13:58
Desc: mssdk 的 pypi 基本信息文件
"""
import re
import ast

import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()


def get_version_string():
    """
    get the mssdk version number
    :return: str version number
    """
    with open("mssdk/__init__.py", "rb") as file:
        version_line = re.search(
            r"__version__\s+=\s+(.*)", file.read().decode("utf-8")
        ).group(1)
        return str(ast.literal_eval(version_line))


setuptools.setup(
    name="mssdk",
    version=get_version_string(),
    author="maxsmart",
    author_email="298038875@qq.com",
    license="MIT",
    description="Python SDK for MaxSmart!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/cdmaxsmart/mssdk",
    packages=setuptools.find_packages(),
    install_requires=[
        "pandas>=0.25.3",
        "requests>=2.22.0",
    ],
    package_data={'': ['*.py', '*.json', "*.pk"]},
    keywords=['finance'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.7',
)



# -*- coding:utf-8 -*-
# /usr/bin/env python
"""
Author: qhsdk
date: 2020/2/13 21:22
desc: 存储和读取Token文件
"""
import os

import pandas as pd

from qhsdk.pro import cons


def set_token(token):
    df = pd.DataFrame([token], columns=['token'])
    user_home = os.path.expanduser('~')
    fp = os.path.join(user_home, cons.TOKEN_F_P)
    df.to_csv(fp, index=False)


def get_token():
    user_home = os.path.expanduser('~')
    fp = os.path.join(user_home, cons.TOKEN_F_P)
    if os.path.exists(fp):
        df = pd.read_csv(fp)
        return str(df.iloc[0]['token'])
    else:
        print(cons.TOKEN_ERR_MSG)
        return None


if __name__ == '__main__':
    pass
